@@ -14,13 +14,16 @@
 # pip install {opts} {packages}
 
 ZUUL_CLONER=/usr/zuul-env/bin/zuul-cloner
-BRANCH_NAME=master
+BRANCH_NAME=stable/queens
+GIT_BASE=${GIT_BASE:-https://git.openstack.org/}
 
 install_project() {
     local project=$1
+    local branch=${2:-$BRANCH_NAME}
+    local module_name=${project//-/_}
 
     set +e
-    project_installed=$(echo "import $project" | python 2>/dev/null ; echo $?)
+    project_installed=$(echo "import $module_name" | python 2>/dev/null ; echo $?)
     set -e
 
     if [ $project_installed -eq 0 ]; then
@@ -36,18 +39,18 @@ install_project() {
         pushd $PROJECT_DIR
         $ZUUL_CLONER --cache-dir \
             /opt/git \
-            --branch $BRANCH_NAME \
-            git://git.openstack.org \
+            --branch $branch \
+            http://git.openstack.org \
             openstack/$project
         cd openstack/$project
         $install_cmd -e .
         popd
     else
         echo "PIP HARDCODE" > /tmp/tox_install.txt
-        if [ -z "$PIP_LOCATION" ]; then
-            PIP_LOCATION="git+https://git.openstack.org/openstack/$project@$BRANCH_NAME#egg=$project"
-        fi
-        $install_cmd -U -e ${PIP_LOCATION}
+        local GIT_REPO="$GIT_BASE/openstack/$project"
+        SRC_DIR="$VIRTUAL_ENV/src/$project"
+        git clone --depth 1 --branch $branch $GIT_REPO $SRC_DIR
+        $install_cmd -U -e $SRC_DIR
     fi
 }
 
@@ -59,6 +62,12 @@ shift
 install_project neutron
 install_project horizon
 install_project networking-bagpipe
+install_project networking-odl 4.0.0
+
+if [ -z "$*" ]; then
+    echo "No packages to be installed."
+    exit 0
+fi
 
 $install_cmd -U $*
 exit $?
